@@ -104,7 +104,11 @@ bool crop_endpoints_to_frame(QPointF *p1, QPointF *p2, int width, int height) {
             case 3: border = QLineF(0, height, width, height); break;
         }
         if (new_points_found == 0) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
             if (QLineF::BoundedIntersection == border.intersect(ridge, &new_p1)) {
+#else
+            if (QLineF::BoundedIntersection == border.intersects(ridge, &new_p1)) {
+#endif
                 // if one point is inside, there will be only 1 intersection point.
                 // But, if one point is on the frame, we might have found it. check that.
                 new_points_found = 1;
@@ -120,7 +124,11 @@ bool crop_endpoints_to_frame(QPointF *p1, QPointF *p2, int width, int height) {
             }
         }
         else {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
             if (QLineF::BoundedIntersection == border.intersect(ridge, &new_p2)) {
+#else
+            if (QLineF::BoundedIntersection == border.intersects(ridge, &new_p2)) {
+#endif
                 // We have to set new_points_found > 1, in order to get
                 // endpoints cropped correctly in the case where both points are
                 // outside the frame, but the ridge passes through the frame.
