@@ -26,10 +26,7 @@
 #include <QCollator>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QStandardItemModel>
 #include <KCategorizedSortFilterProxyModel>
-#include <KCategoryDrawer>
-#include <KLocalizedString>
 #include <KWidgetItemDelegate>
 
 namespace Palapeli
@@ -69,7 +66,7 @@ namespace Palapeli
 				m_iconLabel = new QLabel(this);
 				m_nameLabel = new Palapeli::ElidingLabel(this);
 				m_inputButton = new Palapeli::MouseInputButton(this);
-				connect(m_inputButton, SIGNAL(triggerChanged(const Palapeli::Trigger&)), SIGNAL(triggerChanged(const Palapeli::Trigger&)));
+				connect(m_inputButton, &MouseInputButton::triggerChanged, this, &TriggerListDelegateWidget::triggerChanged);
 				//construct layout
 				QHBoxLayout* layout = new QHBoxLayout;
 				setLayout(layout);
@@ -138,7 +135,7 @@ namespace Palapeli
 				widget->setText(index.data(Qt::DisplayRole).value<QString>());
 				disconnect(widget, 0, this, 0);
 				widget->setTrigger(index.data(TriggerRole).value<Palapeli::Trigger>());
-				connect(widget, SIGNAL(triggerChanged(const Palapeli::Trigger&)), SLOT(slotTriggerChanged(const Palapeli::Trigger&)));
+				connect(widget, &TriggerListDelegateWidget::triggerChanged, this, &TriggerListDelegate::slotTriggerChanged);
 				//adjust widget geometry
 				QRect rect = option.rect;
 				rect.moveTop(0);
@@ -153,7 +150,7 @@ namespace Palapeli
 			{
 				const QModelIndex index = focusedIndex();
 				QAbstractItemModel* model = const_cast<QAbstractItemModel*>(index.model());
-				model->setData(index, qVariantFromValue(newTrigger), Palapeli::TriggerRole);
+				model->setData(index, QVariant::fromValue(newTrigger), Palapeli::TriggerRole);
 				emit triggerChanged();
 			}
 		private:
