@@ -56,7 +56,7 @@ void Palapeli::BooleanPropertyWidget::initialize(const Pala::SlicerProperty* pro
 	m_checkBox->setChecked(property->defaultValue().toBool());
 	QHBoxLayout* layout = new QHBoxLayout;
 	layout->addWidget(m_checkBox);
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	setLayout(layout);
 }
 
@@ -109,7 +109,7 @@ void Palapeli::IntegerPropertyWidget::initialize(const Pala::SlicerProperty* pro
 	QHBoxLayout* layout = new QHBoxLayout;
 	layout->addWidget(usedWidget);
 	usedWidget->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed));
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	setLayout(layout);
 }
 
@@ -150,7 +150,7 @@ void Palapeli::StringPropertyWidget::initialize(const Pala::SlicerProperty* prop
 	QHBoxLayout* layout = new QHBoxLayout;
 	layout->addWidget(usedWidget);
 	usedWidget->setSizePolicy(QSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed));
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	setLayout(layout);
 }
 
